$(function() {
    /* создаем слайдеры */
    $(".slider").slider();
    
    /* устанавливаем начальные значения */
    $(".sl_enable").attr('checked', false);

    $(".slider").each(function() {
        $(this).slider('option', 'value', 33.3);
    });
    
    $(".slider_val").html("33.3 %");
    
    $('.val_field').val('0');
    
    calculate();
    
    /* минимальное и максимальное значение активных слайдеров */
    var min = 0;
    var max = 100;
    
    /*
    Устанавливаем обработчики чекбоксов.
    Использовать событие change не получается, т.к. в IE оно возникает
    после того как checkbox теряет фокус (т.е. после переключения
    checkbox'а нужно кликнуть где-нибудь на странице, чтобы возникло
    событие change)
    */
    $(".sl_enable").click(function() {
        var curId = getCurId(this);
        var curSlider = $('#weight_' + curId);
        if (this.checked) {
            curSlider.slider('disable');
            $("#sv_" + curId).addClass('gray');
        }
        else {
            curSlider.slider('enable');
            $("#sv_" + curId).removeClass('gray');
        }
        setMinMax();
    });
    
    /* обработчик событий slide слайдеров (возникает при перемещении слайдера) */
    $(".slider").bind('slide', function(event, ui) {
        //блокируем перемещение слайдера если оно выходит за допустимые пределы
        if ((ui.value > max) || (ui.value < min)) {
            return false;
        }
        updateSliders(this, ui.value);
        updateLabels();
        calculate();
    })
    .bind('slidestop', function() {
        /*
        Этот обработчик вызывается после перемещения слайдера.
        Нужен для того, чтобы обновить значение текущего слайдера
        (событие slide возникает раньше)
        */
        calculate();
        updateLabels();
    });
    
    /* Эта функция возвращает id текущего слайдера */
    function getCurId(elem) {
        var parentId = $(elem).parent().attr('id');
        return parentId.substring(10);
    }
    
    /*
    Эта функция устанавливает минимально и максимально допустимые значения
    слайдеров.
    */
    function setMinMax() {
        var enabledSliders = $(".slider[aria-disabled!=true]");
        var disabledSliders = $(".slider[aria-disabled=true]");
        
        // определяем сумму значений, установленных на отключенных слайдерах
        var total = 0;
        disabledSliders.each(function() {
            total += $(this).slider('option', 'value');
        });
        
        // задаём минимальные и максимальные значения для включенных слайдеров
        max = 100 - total;
        min = 0;
        if (enabledSliders.length == 1) {
            min = max;
        }
    }
    
    /*
    Изменяет положение слайдеров так чтобы сумма их значений всегда была
    равна 100
    */
    function updateSliders(curSlider, curVal) {
        var enabledSliders = $(".slider[aria-disabled!=true]");
        if (enabledSliders.length == 1) {
            return;
        }
        var newVal = (max - curVal) / (enabledSliders.length - 1);
        enabledSliders.each(function(i, slider) {
            if (slider != curSlider) {
                $(slider).slider('option', 'value', newVal);
            }
        }); 
    }
    
    /* Обновляет надписи с текущими значениями слайдеров */
    function updateLabels() {
        for (var i = 1; i <= 3; i++) {
            var curVal = $("#weight_" + i).slider('option', 'value');
            //округляем до десятых
            curVal = Math.round(curVal*10) / 10;
            $("#sv_" + i).html(curVal + " %");
        }
    }
    
    /* проверка значений, введенных в текстовое поле */
    
    var textFieldVal;
    
    $('.val_field').bind('keydown', function(e) {
        //сохраняем текущее значение
        textFieldVal = $(this).val();
    })
    .bind('keyup', function(e) {
        if (isNaN($(this).val())) {
            $(this).val(textFieldVal);
        }
        calculate();
    });
    
    /* Рассчет взвешенной оценки */
    function calculate() {
        var res = 0;
        
        for (var i = 1; i <= 3; i++) {
            res += $('#val_' + i).val() * $('#weight_' + i).slider('option', 'value') / 100;
        }
        
        //Округляем до сотых
        res = Math.round(res*100) / 100;
        
        $('#results').html('Взвешенная оценка = ' + res);
    }
});
